==> relationalai-0.2.8.tar.gz: relationalai-0.2.8/docs/api_reference/python/std/graphs/README.md <==
# `relationalai.std.graphs`

The `relationalai.std.graphs` namespace contains functions and classes for building
[graphs](./Graph/README.md) from objects in a [model](../../Model/README.md) and doing graph analytics.

- [`graphs.Compute`](./Compute/README.md)
  - [`graphs.Compute.adamic_adar()`](./Compute/adamic_adar.md)
  - [`graphs.compute.avg_clustering_coefficient()`](./Compute/avg_clustering_coefficient.md)
  - [`graphs.Compute.avg_degree()`](./Compute/avg_degree.md)
  - [`graphs.Compute.avg_indegree()`](./Compute/avg_indegree.md)
  - [`graphs.Compute.avg_outdegree()`](./Compute/avg_outdegree.md)
  - [`graphs.Compute.betweenness_centrality()`](./Compute/betweeness_centrality.md)
  - [`graphs.Compute.common_neighbor()`](./Compute/common_neighbor.md)
  - [`graphs.Compute.cosine_similarity()`](./Compute/cosine_similarity.md)
  - [`graphs.Compute.degree_centrality()`](./Compute/degree_centrality.md)
  - [`graphs.Compute.degree()`](./Compute/degree.md)
  - [`graphs.Compute.diameter_range()`](./Compute/diameter_range.md)
  - [`graphs.Compute.distance()`](./Compute/distance.md)
  - [`graphs.Compute.eigenvector_centrality()`](./Compute/eigenvector_centrality.md)
  - [`graph.Compute.indegree()`](./Compute/indegree.md)
  - [`graphs.Compute.is_connected()`](./Compute/is_connected.md)
  - [`graphs.Compute.is_reachable()`](./Compute/is_reachable.md)
  - [`graphs.Compute.is_triangle()`](./Compute/is_triangle.md)
  - [`graphs.Compute.label_propagation()`](./Compute/label_propagation.md)
  - [`graphs.Compute.local_clustering_coefficient()`](./Compute/local_clustering_coefficient.md)
  - [`graphs.Compute.louvain()`](./Compute/louvain.md)
  - [`graphs.Compute.max_degree()`](./Compute/max_degree.md)
  - [`graphs.Compute.max_indegree()`](./Compute/max_indegree.md)
  - [`graphs.Compute.max_outdegree()`](./Compute/max_outdegree.md)
  - [`graphs.Compute.min_degree()`](./Compute/min_degree.md)
  - [`graphs.Compute.min_indegree()`](./Compute/min_indegree.md)
  - [`graphs.Compute.min_outdegree()`](./Compute/min_outdegree.md)
  - [`graphs.Compute.num_edges()`](./Compute/num_edges.md)
  - [`graphs.Compute.num_nodes()`](./Compute/num_nodes.md)
  - [`graphs.Compute.num_triangles()`](./Compute/num_triangles.md)
  - [`graphs.Compute.outdegree()`](./Compute/outdegree.md)
  - [`graphs.Compute.pagerank()`](./Compute/pagerank.md)
  - [`graphs.Compute.preferential_attachment()`](./Compute/preferential_attachment.md)
  - [`graphs.Compute.reachable_from()`](./Compute/reachable_from.md
  - [`graphs.Compute.triangles()`](./Compute/triangles.md)
  - [`graphs.Compute.weakly_connected_component()`](./Compute/weakly_connected_component.md)
  - [`graphs.Compute.weighted_distance()`](./Compute/weighted_distance.md)
  - [`graphs.Compute.weighted_cosine_similarity()`](./Compute/weighted_cosine_similarity.md)
  - [`graphs.Compute.weighted_degree_centrality()`](./Compute/weighted_degree_centrality.md)
  - [`graphs.Compute.weighted_jaccard_similarity()`](./Compute/weighted_jaccard_similarity.md)
- [`graphs.Edge`](./Edge/README.md)
  - [`graphs.Edge.__call__()`](./Edge/call__.md)
  - [`graphs.Edge.add()`](./Edge/add.md)
  - [`graphs.Edge.extend()`](./Edge/extend.md)
- [`graphs.EdgeInstance`](./EdgeInstance/README.md)
  - [`graphs.EdgeInstance.from_`](./EdgeInstance/from_.md)
  - [`graphs.EdgeInstance.to`](./EdgeInstance/to.md)
  - [`graphs.EdgeInstance.set()`](./EdgeInstance/set.md)
- [`graphs.Graph`](./Graph/README.md)
  - [`graphs.Graph.compute`](./Graph/compute.md)
  - [`graphs.Graph.Edge`](./Graph/Edge.md)
  - [`graphs.Graph.fetch()`](./Graph/fetch.md)
  - [`graphs.Graph.id`](./Graph/id.md)
  - [`graphs.Graph.model`](./Graph/model.md)
  - [`graphs.Graph.Node`](./Graph/Node.md)
  - [`graphs.Graph.undirected`](./Graph/undirected.md)
  - [`graphs.Graph.visualize()`](./Graph/visualize.md)

==> relationalai-0.3.2.tar.gz: relationalai-0.3.2/docs/api_reference/python/std/graphs/README.md <==
# `relationalai.std.graphs`

Graphs are comprised of nodes, which are entities from a [model](../../Model/README.md),
and edges representing relationships between nodes.
The `relationalai.std.graphs` namespace contains tools constructing and analyzing graphs.

- [`graphs.Graph`](./Graph/README.md)
  - [`graphs.Graph.compute`](./Graph/compute.md)
  - [`graphs.Graph.Edge`](./Graph/Edge.md)
  - [`graphs.Graph.fetch()`](./Graph/fetch.md)
  - [`graphs.Graph.id`](./Graph/id.md)
  - [`graphs.Graph.model`](./Graph/model.md)
  - [`graphs.Graph.Node`](./Graph/Node.md)
  - [`graphs.Graph.undirected`](./Graph/undirected.md)
  - [`graphs.Graph.visualize()`](./Graph/visualize.md)
- [`graphs.Edge`](./Edge/README.md)
  - [`graphs.Edge.__call__()`](./Edge/call__.md)
  - [`graphs.Edge.add()`](./Edge/add.md)
  - [`graphs.Edge.extend()`](./Edge/extend.md)
- [`graphs.EdgeInstance`](./EdgeInstance/README.md)
  - [`graphs.EdgeInstance.from_`](./EdgeInstance/from_.md)
  - [`graphs.EdgeInstance.to`](./EdgeInstance/to.md)
  - [`graphs.EdgeInstance.set()`](./EdgeInstance/set.md)
- [`graphs.Compute`](./Compute/README.md)
  - [`graphs.Compute.adamic_adar()`](./Compute/adamic_adar.md)
  - [`graphs.compute.avg_clustering_coefficient()`](./Compute/avg_clustering_coefficient.md)
  - [`graphs.Compute.avg_degree()`](./Compute/avg_degree.md)
  - [`graphs.Compute.avg_indegree()`](./Compute/avg_indegree.md)
  - [`graphs.Compute.avg_outdegree()`](./Compute/avg_outdegree.md)
  - [`graphs.Compute.betweenness_centrality()`](./Compute/betweenness_centrality.md)
  - [`graphs.Compute.common_neighbor()`](./Compute/common_neighbor.md)
  - [`graphs.Compute.cosine_similarity()`](./Compute/cosine_similarity.md)
  - [`graphs.Compute.degree_centrality()`](./Compute/degree_centrality.md)
  - [`graphs.Compute.degree()`](./Compute/degree.md)
  - [`graphs.Compute.diameter_range()`](./Compute/diameter_range.md)
  - [`graphs.Compute.distance()`](./Compute/distance.md)
  - [`graphs.Compute.eigenvector_centrality()`](./Compute/eigenvector_centrality.md)
  - [`graphs.Compute.indegree()`](./Compute/indegree.md)
  - [`graphs.Compute.is_connected()`](./Compute/is_connected.md)
  - [`graphs.Compute.is_reachable()`](./Compute/is_reachable.md)
  - [`graphs.Compute.is_triangle()`](./Compute/is_triangle.md)
  - [`graphs.Compute.label_propagation()`](./Compute/label_propagation.md)
  - [`graphs.Compute.local_clustering_coefficient()`](./Compute/local_clustering_coefficient.md)
  - [`graphs.Compute.louvain()`](./Compute/louvain.md)
  - [`graphs.Compute.max_degree()`](./Compute/max_degree.md)
  - [`graphs.Compute.max_indegree()`](./Compute/max_indegree.md)
  - [`graphs.Compute.max_outdegree()`](./Compute/max_outdegree.md)
  - [`graphs.Compute.min_degree()`](./Compute/min_degree.md)
  - [`graphs.Compute.min_indegree()`](./Compute/min_indegree.md)
  - [`graphs.Compute.min_outdegree()`](./Compute/min_outdegree.md)
  - [`graphs.Compute.num_edges()`](./Compute/num_edges.md)
  - [`graphs.Compute.num_nodes()`](./Compute/num_nodes.md)
  - [`graphs.Compute.num_triangles()`](./Compute/num_triangles.md)
  - [`graphs.Compute.outdegree()`](./Compute/outdegree.md)
  - [`graphs.Compute.pagerank()`](./Compute/pagerank.md)
  - [`graphs.Compute.preferential_attachment()`](./Compute/preferential_attachment.md)
  - [`graphs.Compute.reachable_from()`](./Compute/reachable_from.md)
  - [`graphs.Compute.triangles()`](./Compute/triangles.md)
  - [`graphs.Compute.weakly_connected_component()`](./Compute/weakly_connected_component.md)
  - [`graphs.Compute.weighted_distance()`](./Compute/weighted_distance.md)
  - [`graphs.Compute.weighted_cosine_similarity()`](./Compute/weighted_cosine_similarity.md)
  - [`graphs.Compute.weighted_degree_centrality()`](./Compute/weighted_degree_centrality.md)
  - [`graphs.Compute.weighted_jaccard_similarity()`](./Compute/weighted_jaccard_similarity.md)
